==> 1.0.64.tar.gz: android/src/main/java/com/moyoung/moyoung_ble_plugin/event/FileTransHandler.java <==
package com.moyoung.moyoung_ble_plugin.event;

import android.graphics.Bitmap;
import android.os.Handler;
import android.os.Looper;
import android.util.Log;

import com.crrepa.ble.conn.CRPBleConnection;
import com.crrepa.ble.conn.bean.CRPWatchFaceBackgroundInfo;
import com.crrepa.ble.conn.listener.CRPFileTransListener;
import com.moyoung.moyoung_ble_plugin.ErrorConstant;
import com.moyoung.moyoung_ble_plugin.base.BaseConnectionEventChannelHandler;
import com.moyoung.moyoung_ble_plugin.common.GsonUtils;
import com.moyoung.moyoung_ble_plugin.common.ImageUtils;
import com.moyoung.moyoung_ble_plugin.model.FileTransBean;
import com.moyoung.moyoung_ble_plugin.model.WatchFaceBgBean;

import io.flutter.plugin.common.MethodCall;

class FileTransHandler extends BaseConnectionEventChannelHandler {
    private static final FileTransHandler instance = new FileTransHandler();
    public static FileTransHandler getInstance() {
        return instance;
    }
    @Override
    public void setConnListener(CRPBleConnection connection, MethodCall call) {
        String jsonStr = call.argument("watchFaceBackgroundInfo");
        WatchFaceBgBean watchFaceBgBean = GsonUtils.get().fromJson(jsonStr, WatchFaceBgBean.class);
        Bitmap bitmap = ImageUtils.cropBitmap(watchFaceBgBean.getBitmap(), watchFaceBgBean.getWidth(), watchFaceBgBean.getHeight());
        Bitmap thumbBitmap = null;
        if (watchFaceBgBean.getThumbHeight() != 0) {
            thumbBitmap = ImageUtils.cropBitmap(watchFaceBgBean.getThumbBitmap(), watchFaceBgBean.getThumbWidth(), watchFaceBgBean.getThumbHeight());
        }
        CRPWatchFaceBackgroundInfo backgroundInfo = new CRPWatchFaceBackgroundInfo(bitmap, thumbBitmap, watchFaceBgBean.getType());
//        CRPWatchFaceBackgroundInfo backgroundInfo = new CRPWatchFaceBackgroundInfo(watchFaceBgBean.getBitmap(), watchFaceBgBean.getThumbBitmap(), watchFaceBgBean.getType());

        sendWatchFaceBackground(connection, backgroundInfo);
    }

    private void sendWatchFaceBackground(CRPBleConnection connection, CRPWatchFaceBackgroundInfo backgroundInfo) {
        connection.sendWatchFaceBackground(backgroundInfo, new CRPFileTransListener() {
            @Override
            public void onTransProgressStarting() {
                if (eventSink == null) {
                    return;
                }
                FileTransBean transBean = new FileTransBean(FileTransBean.TRANSSTART);
                String bgProgress = GsonUtils.get().toJson(transBean, FileTransBean.class);
                new Handler(Looper.getMainLooper()).post(() -> eventSink.success(bgProgress));
            }

            @Override
            public void onTransProgressChanged(int progress) {
                if (eventSink == null) {
                    return;
                }
                FileTransBean transBean = new FileTransBean(FileTransBean.TRANSCHANGED);
                transBean.setProgress(progress);
                String bgProgress = GsonUtils.get().toJson(transBean, FileTransBean.class);
                new Handler(Looper.getMainLooper()).post(() -> eventSink.success(bgProgress));
            }

            @Override
            public void onTransCompleted() {
                if (eventSink == null) {
                    return;
                }
                FileTransBean transBean = new FileTransBean(FileTransBean.TRANSCOMPLETED);
                transBean.setProgress(100);
                String bgProgress = GsonUtils.get().toJson(transBean, FileTransBean.class);
                new Handler(Looper.getMainLooper()).post(() -> eventSink.success(bgProgress));
            }

            @Override
            public void onError(int i) {
                if (eventSink == null) {
                    return;
                }
                FileTransBean transBean = new FileTransBean(FileTransBean.ERROR);
                transBean.setError(i);
                transBean.setProgress(-1);
                String bgProgress = GsonUtils.get().toJson(transBean, FileTransBean.class);
                new Handler(Looper.getMainLooper()).post(() -> eventSink.success(bgProgress));
            }
        });
    }
}

==> 1.0.70.tar.gz: android/src/main/java/com/moyoung/moyoung_ble_plugin/event/FileTransHandler.java <==
package com.moyoung.moyoung_ble_plugin.event;

import android.graphics.Bitmap;
import android.os.Handler;
import android.os.Looper;
import android.util.Log;

import com.crrepa.ble.conn.CRPBleConnection;
import com.crrepa.ble.conn.bean.CRPWatchFaceBackgroundInfo;
import com.crrepa.ble.conn.listener.CRPFileTransListener;
import com.moyoung.moyoung_ble_plugin.ErrorConstant;
import com.moyoung.moyoung_ble_plugin.base.BaseConnectionEventChannelHandler;
import com.moyoung.moyoung_ble_plugin.common.GsonUtils;
import com.moyoung.moyoung_ble_plugin.common.ImageUtils;
import com.moyoung.moyoung_ble_plugin.model.FileTransBean;
import com.moyoung.moyoung_ble_plugin.model.WatchFaceBgBean;

import io.flutter.plugin.common.MethodCall;

class FileTransHandler extends BaseConnectionEventChannelHandler {
    private static final FileTransHandler instance = new FileTransHandler();
    public static FileTransHandler getInstance() {
        return instance;
    }
    @Override
    public void setConnListener(CRPBleConnection connection, MethodCall call) {
        String jsonStr = call.argument("watchFaceBackgroundInfo");
        WatchFaceBgBean watchFaceBgBean = GsonUtils.get().fromJson(jsonStr, WatchFaceBgBean.class);
        Bitmap bitmap = ImageUtils.resizingBitmap(watchFaceBgBean.getBitmap(), watchFaceBgBean.getWidth(), watchFaceBgBean.getHeight());
        Bitmap thumbBitmap = null;
        if (watchFaceBgBean.getThumbHeight() != 0) {
            thumbBitmap = ImageUtils.resizingBitmap(watchFaceBgBean.getThumbBitmap(), watchFaceBgBean.getThumbWidth(), watchFaceBgBean.getThumbHeight());
        }
        CRPWatchFaceBackgroundInfo backgroundInfo = new CRPWatchFaceBackgroundInfo(bitmap, thumbBitmap, watchFaceBgBean.getType());

        sendWatchFaceBackground(connection, backgroundInfo);
    }

    private void sendWatchFaceBackground(CRPBleConnection connection, CRPWatchFaceBackgroundInfo backgroundInfo) {
        connection.sendWatchFaceBackground(backgroundInfo, new CRPFileTransListener() {
            @Override
            public void onTransProgressStarting() {
                if (eventSink == null) {
                    return;
                }
                FileTransBean transBean = new FileTransBean(FileTransBean.TRANSSTART);
                String bgProgress = GsonUtils.get().toJson(transBean, FileTransBean.class);
                new Handler(Looper.getMainLooper()).post(() -> eventSink.success(bgProgress));
            }

            @Override
            public void onTransProgressChanged(int progress) {
                if (eventSink == null) {
                    return;
                }
                FileTransBean transBean = new FileTransBean(FileTransBean.TRANSCHANGED);
                transBean.setProgress(progress);
                String bgProgress = GsonUtils.get().toJson(transBean, FileTransBean.class);
                new Handler(Looper.getMainLooper()).post(() -> eventSink.success(bgProgress));
            }

            @Override
            public void onTransCompleted() {
                if (eventSink == null) {
                    return;
                }
                FileTransBean transBean = new FileTransBean(FileTransBean.TRANSCOMPLETED);
                transBean.setProgress(100);
                String bgProgress = GsonUtils.get().toJson(transBean, FileTransBean.class);
                new Handler(Looper.getMainLooper()).post(() -> eventSink.success(bgProgress));
            }

            @Override
            public void onError(int i) {
                if (eventSink == null) {
                    return;
                }
                FileTransBean transBean = new FileTransBean(FileTransBean.ERROR);
                transBean.setError(i);
                transBean.setProgress(-1);
                String bgProgress = GsonUtils.get().toJson(transBean, FileTransBean.class);
                new Handler(Looper.getMainLooper()).post(() -> eventSink.success(bgProgress));
            }
        });
    }
}
